@@ -1,27 +1,34 @@
 
-/***************************************************************************
-                          xsldbgevent.c  -  event to notify app of
-                                                   data from xsldbg
-                             -------------------
-    begin                : Fri Feb 1 2001
-    copyright            : (C) 2001 by Keith Isdale
-    email                : k_isdale@tpg.com.au
- ***************************************************************************/
+/**
+ *
+ *  This file is part of the kdewebdev package
+ *  Copyright (c) 2001 Keith Isdale <keith@kdewebdev.org>
+ *
+ *  This library is free software; you can redistribute it and/or 
+ *  modify it under the terms of the GNU General Public License as 
+ *  published by the Free Software Foundation; either version 2 of 
+ *  the License, or (at your option) any later version.
+ *
+ *  This library is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ *  Library General Public License for more details.
+ *
+ *  You should have received a copy of the GNU Library General Public License
+ *  along with this library; see the file COPYING.LIB.  If not, write to
+ *  the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ *  Boston, MA 02110-1301, USA.
+ **/
 
-/***************************************************************************
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- ***************************************************************************/
 
-#include <qapplication.h>
-#include <qtimer.h>
-#include <qfile.h>
+#include <QApplication>
+#include <QTimer>
+#include <QFile>
+#include <QTimerEvent>
+#include <QEvent>
 #include <kurl.h>
-#include <qtextstream.h>
+#include <QDebug>
+#include <QTextStream>
 
 #include <libxslt/xsltInternals.h>
 
@@ -41,7 +48,7 @@ XsldbgEventData::XsldbgEventData()
   int column;
 
   for (column = 0; column < XSLDBGEVENT_COLUMNS; column++){
-    textValues[column] = QString::null;
+    textValues[column].clear();
   }
 
  for (column = 0; column < XSLDBGEVENT_COLUMNS; column++){
@@ -54,7 +61,7 @@ XsldbgEventData::~XsldbgEventData()
 {
 }
 
-void XsldbgEventData::setText(int column, QString text)
+void XsldbgEventData::setText(int column, const QString & text)
 {
   if ((column >= 0) && (column < XSLDBGEVENT_COLUMNS))
     textValues[column] = text;
@@ -66,7 +73,7 @@ QString XsldbgEventData::getText(int column)
   if ((column >= 0) && (column < XSLDBGEVENT_COLUMNS))
     return textValues[column];
   else
-    return QString::null;
+    return QString();
 }
 
 
@@ -129,6 +136,11 @@ XsldbgEvent::XsldbgEvent(XsldbgMessageEnum type, const void *data)
 
 XsldbgEvent::~XsldbgEvent()
 {
+  XsldbgEventData *eventData;
+  for (int index = 0; index < list.count(); ++index){
+      eventData = list.takeAt(index);
+      delete eventData;
+  }
 }
 
 
@@ -163,7 +175,7 @@ XsldbgEventData *XsldbgEvent::createEventData(XsldbgMessageEnum type, const void
       break;
 
     /* provide more informatiom about state of xsldbg (optional) */
-    case XSLDBG_MSG_PROCESSING_RESULT:       /* 8: An error occured performing command
+    case XSLDBG_MSG_PROCESSING_RESULT:       /* 8: An error occurred performing command
                                          * requested command */
       if (msgData != 0L){
 	xsldbgErrorMsgPtr msg = (xsldbgErrorMsgPtr)msgData;
@@ -186,22 +198,21 @@ XsldbgEventData *XsldbgEvent::createEventData(XsldbgMessageEnum type, const void
       break;
 
     case XSLDBG_MSG_PARAMETER_CHANGED:       /* 12: Response to showparam command */
-      handleParameterItem(result, msgData);
       break;
 
     case XSLDBG_MSG_TEXTOUT:         /* 13 : Free form text from xsldg */
-      /* this is going to be most common and its so simple we can handle
+      /* this is going to be most common and it is so simple we can handle
        it here */
       result->setText(0, XsldbgDebuggerBase::fromUTF8((xmlChar*)msgData));
       break;
 
-    case XSLDBG_MSG_FILEOUT:         /* 14 : Response to cat commmand, ie
+    case XSLDBG_MSG_FILEOUT:         /* 14 : Response to cat command, ie
                                  * Free form text in file */
       /* this is actualy the  file to load */
       {
-	KURL url(XsldbgDebuggerBase::fromUTF8FileName((xmlChar*)msgData));
+	KUrl url(XsldbgDebuggerBase::fromUTF8FileName((xmlChar*)msgData));
 	if (!url.isLocalFile()){
-	    qDebug("Remote path to temp file %s unsupported, unable to read message from xsldbg", url.prettyURL().local8Bit().data());
+	    qDebug() << "Remote path to temp file" << url.prettyUrl() << " is unsupported, unable to read message from xsldbg";
 	    break;
 	}
 	    
@@ -209,10 +220,10 @@ XsldbgEventData *XsldbgEvent::createEventData(XsldbgMessageEnum type, const void
 	QString outputText;
 	if (!fileName.isNull()){
 	  QFile file (fileName);
-	  if (file.open(IO_ReadOnly)){
+	  if (file.open(QIODevice::ReadOnly)){
 	    QTextStream textFile(&file);
 	    QString textIn = "";
-	    textFile.setEncoding(QTextStream::UnicodeUTF8);
+	    textFile.setCodec(QTextCodec::codecForName("UTF8"));
 	    while (1){
 	      textIn = textFile.readLine();
 	      if (textIn.isNull())
@@ -237,7 +248,7 @@ XsldbgEventData *XsldbgEvent::createEventData(XsldbgMessageEnum type, const void
       handleGlobalVariableItem(result, msgData);
       break;
 
-    case XSLDBG_MSG_TEMPLATE_CHANGED:        /* 17 : Response to templates commmand
+    case XSLDBG_MSG_TEMPLATE_CHANGED:        /* 17 : Response to templates command
                                          * ie template details */
       handleTemplateItem(result, msgData);
       break;
@@ -277,12 +288,10 @@ XsldbgEventData *XsldbgEvent::createEventData(XsldbgMessageEnum type, const void
 
 void XsldbgEvent::emitMessage(XsldbgDebuggerBase *debugger)
 {
-  XsldbgEventData *eventData;
-
   this->debugger = debugger;
 
-  for (eventData = list.first(); eventData != 0L; eventData = list.next()){
-    emitMessage(eventData);
+  for (int index = 0; index < list.count(); ++index){
+    emitMessage(list[index]);
   }
 
   /* make sure that we only temporarily set the value for debugger*/
@@ -321,6 +330,7 @@ void XsldbgEvent::emitMessage(XsldbgEventData *eventData)
     case XSLDBG_MSG_THREAD_DEAD:     /* 4: The xsldbg thread died */
       /* the debugger has stopped is about to stop */
       debugger->setInitialized(false);
+      emit debugger->debuggerStopped();
       break;
 
     /* input status ( once thread is running) */
@@ -345,7 +355,7 @@ void XsldbgEvent::emitMessage(XsldbgEventData *eventData)
       break;
 
     /* provide more informatiom about state of xsldbg (optional) */
-    case XSLDBG_MSG_PROCESSING_RESULT:       /* 8: An error occured performing command
+    case XSLDBG_MSG_PROCESSING_RESULT:       /* 8: An error occurred performing command
                                          * requested command */
       if (!eventData->getText(0).isNull())
 	updateText.append(eventData->getText(0));
@@ -369,11 +379,10 @@ void XsldbgEvent::emitMessage(XsldbgEventData *eventData)
       break;
 
     case XSLDBG_MSG_PARAMETER_CHANGED:       /* 12: Response to showparam command */
-      handleParameterItem(eventData, 0L);
       break;
 
     case XSLDBG_MSG_TEXTOUT:         /* 13 : Free form text from xsldg */
-      /* this is going to be most common and its so simple we can handle
+      /* this is going to be most common and it is so simple we can handle
        it here */
       /*
       emit debugger->showMessage(eventData->getText(0));
@@ -382,7 +391,7 @@ void XsldbgEvent::emitMessage(XsldbgEventData *eventData)
 	updateText.append(eventData->getText(0));
       break;
 
- case XSLDBG_MSG_FILEOUT:         /* 14 : Response to cat commmand */
+ case XSLDBG_MSG_FILEOUT:         /* 14 : Response to cat command */
       if (!eventData->getText(0).isNull())
 	updateText.append(eventData->getText(0));
 	break;
@@ -397,7 +406,7 @@ void XsldbgEvent::emitMessage(XsldbgEventData *eventData)
       handleGlobalVariableItem(eventData, 0L);
       break;
 
-    case XSLDBG_MSG_TEMPLATE_CHANGED:        /* 17 : Response to templates commmand
+    case XSLDBG_MSG_TEMPLATE_CHANGED:        /* 17 : Response to templates command
                                          * ie template details */
       handleTemplateItem(eventData, 0L);
       break;
@@ -715,30 +724,6 @@ void XsldbgEvent::handleSourceItem(XsldbgEventData *eventData, const  void *msgD
   }
 }
 
-void XsldbgEvent::handleParameterItem(XsldbgEventData *eventData, const  void *msgData)
-{
-  if (eventData != 0L){
-    if (beenCreated == false){
-      /* add our specific data to eventData*/
-      if (msgData != 0L){
-	parameterItemPtr paramItem = (parameterItemPtr)msgData;
-	QString name, value;
-
-	name = XsldbgDebuggerBase::fromUTF8(paramItem->name);
-	value = XsldbgDebuggerBase::fromUTF8(paramItem->value);
-
-	eventData->setText(0, name);
-	eventData->setText(1, value);
-      }
-    }else{
-      /* emit the event data via debugger*/
-      emit debugger->parameterItem(eventData->getText(0), /* param name*/
-				   eventData->getText(1) /* param value*/);
-    }
-  }
-}
-
-
 void XsldbgEvent::handleCallStackItem(XsldbgEventData *eventData, const  void *msgData)
 {
   if (eventData != 0L){
@@ -811,47 +796,3 @@ void XsldbgEvent::handleResolveItem(XsldbgEventData *eventData, const  void *msg
   }
 }
 
-
-void XsldbgEvent::handleIntOptionItem(XsldbgEventData *eventData, const  void *msgData)
-{
-  if (eventData != 0L){
-    if (beenCreated == false){
-      /* add our specific data to eventData*/
-      if (msgData != 0L){
-	parameterItemPtr paramItem = (parameterItemPtr)msgData;
-	eventData->setText(0, XsldbgDebuggerBase::fromUTF8(paramItem->name));
-	eventData->setInt(0, paramItem->intValue);
-      }
-    }else{
-      /* emit the event data via debugger*/
-      emit debugger->intOptionItem(eventData->getText(0), /* option name*/
-				   eventData->getInt(0) /* value*/);
-    }
-  }
-}
-
-
-void XsldbgEvent::handleStringOptionItem(XsldbgEventData *eventData, const  void *msgData)
-{
-  if (eventData != 0L){
-    if (beenCreated == false){
-      /* add our specific data to eventData*/
-      if (msgData != 0L){
-	parameterItemPtr paramItem = (parameterItemPtr)msgData;
-	eventData->setText(0, XsldbgDebuggerBase::fromUTF8(paramItem->name));
-	eventData->setText(1, XsldbgDebuggerBase::fromUTF8(paramItem->value));
-      }
-    }else{
-      /* emit the event data via debugger*/
-      emit debugger->stringOptionItem(eventData->getText(0), /* option name*/
-				   eventData->getText(1) /* value*/);
-    }
-  }
-}
-
-
-
-void XsldbgEventDataList::deleteItem( QPtrCollection::Item d )
-{
-    if ( del_item ) delete (XsldbgEventData *)d;
-}
